@@ -4,7 +4,7 @@ Main interface for sso-admin service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_sso_admin import (
         Client,
         ListAccountAssignmentCreationStatusPaginator,
@@ -20,10 +20,8 @@ Usage::
         SSOAdminClient,
     )
 
-    session = boto3.Session()
-
-    client: SSOAdminClient = boto3.client("sso-admin")
-    session_client: SSOAdminClient = session.client("sso-admin")
+    session = Session()
+    client: SSOAdminClient = session.client("sso-admin")
 
     list_account_assignment_creation_status_paginator: ListAccountAssignmentCreationStatusPaginator = client.get_paginator("list_account_assignment_creation_status")
     list_account_assignment_deletion_status_paginator: ListAccountAssignmentDeletionStatusPaginator = client.get_paginator("list_account_assignment_deletion_status")
