@@ -1,7 +1,7 @@
 """
 Type annotations for sso-admin service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/)
 
 Usage::
 
@@ -88,7 +88,7 @@ class Exceptions:
 class SSOAdminClient(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/)
     """
 
     meta: ClientMeta
@@ -99,7 +99,7 @@ class SSOAdminClient(BaseClient):
         SSOAdminClient exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#exceptions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#exceptions)
         """
 
     def attach_managed_policy_to_permission_set(
@@ -109,7 +109,7 @@ class SSOAdminClient(BaseClient):
         Attaches an IAM managed policy ARN to a permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.attach_managed_policy_to_permission_set)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#attach_managed_policy_to_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#attach_managed_policy_to_permission_set)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -117,7 +117,7 @@ class SSOAdminClient(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#can_paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#can_paginate)
         """
 
     def create_account_assignment(
@@ -135,7 +135,7 @@ class SSOAdminClient(BaseClient):
         a specified permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.create_account_assignment)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#create_account_assignment)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#create_account_assignment)
         """
 
     def create_instance_access_control_attribute_configuration(
@@ -149,7 +149,7 @@ class SSOAdminClient(BaseClient):
         Amazon Web Services SSO instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.create_instance_access_control_attribute_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#create_instance_access_control_attribute_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#create_instance_access_control_attribute_configuration)
         """
 
     def create_permission_set(
@@ -166,7 +166,7 @@ class SSOAdminClient(BaseClient):
         Creates a permission set within a specified SSO instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.create_permission_set)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#create_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#create_permission_set)
         """
 
     def delete_account_assignment(
@@ -184,7 +184,7 @@ class SSOAdminClient(BaseClient):
         a specified permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.delete_account_assignment)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#delete_account_assignment)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#delete_account_assignment)
         """
 
     def delete_inline_policy_from_permission_set(
@@ -194,7 +194,7 @@ class SSOAdminClient(BaseClient):
         Deletes the inline policy from a specified permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.delete_inline_policy_from_permission_set)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#delete_inline_policy_from_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#delete_inline_policy_from_permission_set)
         """
 
     def delete_instance_access_control_attribute_configuration(
@@ -206,7 +206,7 @@ class SSOAdminClient(BaseClient):
         have been configured.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.delete_instance_access_control_attribute_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#delete_instance_access_control_attribute_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#delete_instance_access_control_attribute_configuration)
         """
 
     def delete_permission_set(self, *, InstanceArn: str, PermissionSetArn: str) -> Dict[str, Any]:
@@ -214,7 +214,7 @@ class SSOAdminClient(BaseClient):
         Deletes the specified permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.delete_permission_set)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#delete_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#delete_permission_set)
         """
 
     def describe_account_assignment_creation_status(
@@ -224,7 +224,7 @@ class SSOAdminClient(BaseClient):
         Describes the status of the assignment creation request.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_creation_status)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#describe_account_assignment_creation_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#describe_account_assignment_creation_status)
         """
 
     def describe_account_assignment_deletion_status(
@@ -234,7 +234,7 @@ class SSOAdminClient(BaseClient):
         Describes the status of the assignment deletion request.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_deletion_status)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#describe_account_assignment_deletion_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#describe_account_assignment_deletion_status)
         """
 
     def describe_instance_access_control_attribute_configuration(
@@ -246,7 +246,7 @@ class SSOAdminClient(BaseClient):
         specified Amazon Web Services SSO instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.describe_instance_access_control_attribute_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#describe_instance_access_control_attribute_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#describe_instance_access_control_attribute_configuration)
         """
 
     def describe_permission_set(
@@ -256,7 +256,7 @@ class SSOAdminClient(BaseClient):
         Gets the details of the permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#describe_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#describe_permission_set)
         """
 
     def describe_permission_set_provisioning_status(
@@ -266,7 +266,7 @@ class SSOAdminClient(BaseClient):
         Describes the status for the given permission set provisioning request.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set_provisioning_status)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#describe_permission_set_provisioning_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#describe_permission_set_provisioning_status)
         """
 
     def detach_managed_policy_from_permission_set(
@@ -276,7 +276,7 @@ class SSOAdminClient(BaseClient):
         Detaches the attached IAM managed policy ARN from the specified permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.detach_managed_policy_from_permission_set)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#detach_managed_policy_from_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#detach_managed_policy_from_permission_set)
         """
 
     def generate_presigned_url(
@@ -290,7 +290,7 @@ class SSOAdminClient(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#generate_presigned_url)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#generate_presigned_url)
         """
 
     def get_inline_policy_for_permission_set(
@@ -300,7 +300,7 @@ class SSOAdminClient(BaseClient):
         Obtains the inline policy assigned to the permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.get_inline_policy_for_permission_set)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_inline_policy_for_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_inline_policy_for_permission_set)
         """
 
     def list_account_assignment_creation_status(
@@ -316,7 +316,7 @@ class SSOAdminClient(BaseClient):
         for a specified SSO instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_creation_status)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_account_assignment_creation_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_account_assignment_creation_status)
         """
 
     def list_account_assignment_deletion_status(
@@ -332,7 +332,7 @@ class SSOAdminClient(BaseClient):
         for a specified SSO instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_deletion_status)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_account_assignment_deletion_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_account_assignment_deletion_status)
         """
 
     def list_account_assignments(
@@ -349,7 +349,7 @@ class SSOAdminClient(BaseClient):
         specified permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignments)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_account_assignments)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_account_assignments)
         """
 
     def list_accounts_for_provisioned_permission_set(
@@ -366,7 +366,7 @@ class SSOAdminClient(BaseClient):
         provisioned.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_accounts_for_provisioned_permission_set)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_accounts_for_provisioned_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_accounts_for_provisioned_permission_set)
         """
 
     def list_instances(
@@ -376,7 +376,7 @@ class SSOAdminClient(BaseClient):
         Lists the SSO instances that the caller has access to.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_instances)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_instances)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_instances)
         """
 
     def list_managed_policies_in_permission_set(
@@ -391,7 +391,7 @@ class SSOAdminClient(BaseClient):
         Lists the IAM managed policy that is attached to a specified permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_managed_policies_in_permission_set)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_managed_policies_in_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_managed_policies_in_permission_set)
         """
 
     def list_permission_set_provisioning_status(
@@ -407,7 +407,7 @@ class SSOAdminClient(BaseClient):
         instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_set_provisioning_status)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_permission_set_provisioning_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_permission_set_provisioning_status)
         """
 
     def list_permission_sets(
@@ -417,7 +417,7 @@ class SSOAdminClient(BaseClient):
         Lists the  PermissionSet s in an SSO instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_permission_sets)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_permission_sets)
         """
 
     def list_permission_sets_provisioned_to_account(
@@ -434,7 +434,7 @@ class SSOAdminClient(BaseClient):
         Services account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets_provisioned_to_account)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_permission_sets_provisioned_to_account)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_permission_sets_provisioned_to_account)
         """
 
     def list_tags_for_resource(
@@ -444,7 +444,7 @@ class SSOAdminClient(BaseClient):
         Lists the tags that are attached to a specified resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_tags_for_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_tags_for_resource)
         """
 
     def provision_permission_set(
@@ -460,7 +460,7 @@ class SSOAdminClient(BaseClient):
         target.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.provision_permission_set)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#provision_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#provision_permission_set)
         """
 
     def put_inline_policy_to_permission_set(
@@ -470,7 +470,7 @@ class SSOAdminClient(BaseClient):
         Attaches an IAM inline policy to a permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.put_inline_policy_to_permission_set)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#put_inline_policy_to_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#put_inline_policy_to_permission_set)
         """
 
     def tag_resource(
@@ -480,7 +480,7 @@ class SSOAdminClient(BaseClient):
         Associates a set of tags with a specified resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.tag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#tag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#tag_resource)
         """
 
     def untag_resource(
@@ -490,7 +490,7 @@ class SSOAdminClient(BaseClient):
         Disassociates a set of tags from a specified resource.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.untag_resource)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#untag_resource)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#untag_resource)
         """
 
     def update_instance_access_control_attribute_configuration(
@@ -505,7 +505,7 @@ class SSOAdminClient(BaseClient):
         (ABAC).
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.update_instance_access_control_attribute_configuration)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#update_instance_access_control_attribute_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#update_instance_access_control_attribute_configuration)
         """
 
     def update_permission_set(
@@ -521,7 +521,7 @@ class SSOAdminClient(BaseClient):
         Updates an existing permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.update_permission_set)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#update_permission_set)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#update_permission_set)
         """
 
     @overload
@@ -530,7 +530,7 @@ class SSOAdminClient(BaseClient):
     ) -> ListAccountAssignmentCreationStatusPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
         """
 
     @overload
@@ -539,7 +539,7 @@ class SSOAdminClient(BaseClient):
     ) -> ListAccountAssignmentDeletionStatusPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
         """
 
     @overload
@@ -548,7 +548,7 @@ class SSOAdminClient(BaseClient):
     ) -> ListAccountAssignmentsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
         """
 
     @overload
@@ -557,14 +557,14 @@ class SSOAdminClient(BaseClient):
     ) -> ListAccountsForProvisionedPermissionSetPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_instances"]) -> ListInstancesPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
         """
 
     @overload
@@ -573,7 +573,7 @@ class SSOAdminClient(BaseClient):
     ) -> ListManagedPoliciesInPermissionSetPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
         """
 
     @overload
@@ -582,7 +582,7 @@ class SSOAdminClient(BaseClient):
     ) -> ListPermissionSetProvisioningStatusPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
         """
 
     @overload
@@ -591,7 +591,7 @@ class SSOAdminClient(BaseClient):
     ) -> ListPermissionSetsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
         """
 
     @overload
@@ -600,7 +600,7 @@ class SSOAdminClient(BaseClient):
     ) -> ListPermissionSetsProvisionedToAccountPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
         """
 
     @overload
@@ -609,5 +609,5 @@ class SSOAdminClient(BaseClient):
     ) -> ListTagsForResourcePaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#get_paginator)
         """
